StepF <- function()
{
#
#  R statistical program script to estimate transfer function for peak snowpack using stepwise 
#  regression of a multiple linear regression model.  Change file names to input and output files 
#  for the Fort Peck Lake watershed (FTPK) or lower Lake Sakakawea watershed (SAKA).
#  Output files are specified throughout the script.
#
#  Set output file name.
#
    sink("OUTPUT/PSWE.SAKA.Stepwise.Forward.out")
#
#  Read input files.
#
    CalibData  <- read.table("INPUT/PSWE_TAVE_PREC_STN_SAKA_1992-2011.CALIB.txt", header=TRUE)
#
#  Linear regression for Peak Snow Water Equivalent in a given year.
#
    yy_null = lm(PEAKSWE ~ 1, data=CalibData)
    yy_full= lm(PEAKSWE ~ PRECJASPLN + PRECONDPLN + PRECJFMPLN + PRECAMJPLN + PRECJASFTH + PRECONDFTH + PRECJFMFTH + PRECAMJFTH + PRECJASMTN + PRECONDMTN + PRECJFMMTN + PRECAMJMTN + TAVEJASPLN + TAVEONDPLN + TAVEJFMPLN + TAVEAMJPLN + TAVEJASFTH + TAVEONDFTH + TAVEJFMFTH + TAVEAMJFTH + TAVEJASMTN + TAVEONDMTN + TAVEJFMMTN + TAVEAMJMTN, data=CalibData)
#
    print(" ")
    print("*************************************************************************")
    print("* Ouput from linear model before stepwise regression.                   *")
    print("*************************************************************************")
    print(" ")
    print(summary(yy_full))
#
#  Stepwise regression of variables.
#

    print(" ")
    print("*************************************************************************")
    print("* Ouput from stepwise regression.                                       *")
    print("*************************************************************************")
    print(" ")

    yy_step = step(yy_null, scope=list(lower=yy_null, upper=yy_full), direction="forward", trace=3)
    print(summary(yy_step))
#
#  Return output to the terminal.
#
    sink()
}
