lm_FTPK <- function()
{
#
#  R statistical program script to finalize transfer function for peak snowpack using
#  regression of a multiple linear regression model.
#  Output files are specified throughout the script.
#
#  Set output file name.
#
    sink("OUTPUT/PSWE.FTPK.FinalMLR.out")
#
#  Read input files.
#
    CalibData <- read.table("INPUT/PSWE_TAVE_PREC_STN_FTPK_1992-2011.CALIB.txt", header=TRUE)
    ValidData <- read.table("INPUT/PSWE_TAVE_PREC_STN_FTPK_1992-2011.VALID.txt", header=TRUE)
    CCSM3Data <- read.table("INPUT/CCSM3.FTPK.1992-2099.txt", header=TRUE)
    CCSM4Data <- read.table("INPUT/CCSM4.FTPK.1992-2099.txt", header=TRUE)
#
#  Linear regression for Peak Snow Water Equivalent in a given year.
#
    yy = lm(PEAKSWE ~ PRECJFMFTH + PRECONDFTH + TAVEAMJPLN + PRECJFMMTN + TAVEONDPLN, data=CalibData)
    print(summary(yy))
#
    print(" ")
    print("*************************************************************************")
    print("* Ouput of coefficients from stepwise regression.                       *")
    print("*************************************************************************")
    print(" ")

    print(coefficients(yy))
#
#  Write out observed verus modeled for calibration dataset.
#
    yy_fit = fitted(yy)
    write.table(cbind(CalibData$YEAR, CalibData$PEAKSWE, yy_fit), file="OUTPUT/FTPK_PSWE_CALIB_1992-2011.out")
#
#  Predict peak SWE using validation dataset.
#
    SWE_projected = predict(yy, newdata=ValidData, interval="prediction")
    write.table(cbind(ValidData$YEAR, ValidData$PEAKSWE, SWE_projected), file="OUTPUT/FTPK_PSWE_VALID_1992-2011.out")
#
#  Predict peak SWE using CCSM output temperature and precipitation.
#
    SWE_projected = predict(yy, newdata=CCSM3Data, interval="prediction")
    write.table(cbind(CCSM3Data$YEAR, SWE_projected), file="OUTPUT/FTPK_PSWE_CCSM3_1992-2099.out")
#
    SWE_projected = predict(yy, newdata=CCSM4Data, interval="prediction")
    write.table(cbind(CCSM4Data$YEAR, SWE_projected), file="OUTPUT/FTPK_PSWE_CCSM4_1992-2099.out")
#
#  Return output to the terminal.
#
    sink()
}
